@@ -2,7 +2,7 @@
  * @file export.c  OPML feed list import & export
  *
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004-2011 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2004-2015 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,28 +19,32 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <sys/stat.h>
-
 #include "export.h"
 
+#include <errno.h>
+#include <glib.h>
 #include <libxml/tree.h>
+#include <sys/stat.h>
 
+#include "auth.h"
 #include "common.h"
 #include "db.h"
 #include "debug.h"
 #include "favicon.h"
 #include "feedlist.h"
 #include "folder.h"
-#include "vfolder.h"
+#include "node.h"
 #include "xml.h"
-#include "fl_sources/node_source.h"
-#include "ui/ui_node.h"
+#include "ui/ui_common.h"
+#include "ui/feed_list_node.h"
 
 struct exportData {
 	gboolean	trusted; /**< Include all the extra Liferea-specific tags */
 	xmlNodePtr	cur;
 };
 
+static void export_node_children (nodePtr node, xmlNodePtr cur, gboolean trusted);
+
 /* Used for exporting, this adds a folder or feed's node to the XML tree */
 static void
 export_append_node_tag (nodePtr node, gpointer userdata)
@@ -50,8 +54,8 @@ export_append_node_tag (nodePtr node, gpointer userdata)
 	xmlNodePtr	childNode;
 	gchar		*tmp;
 
-	// FIXME: use node type capability for this condition
-	if (!internal && (IS_NODE_SOURCE (node) || IS_VFOLDER (node)))
+	/* When exporting external OPML do not export every node type... */
+	if (!(internal || (NODE_TYPE (node)->capabilities & NODE_CAPABILITY_EXPORT)))
 		return;
 	
 	childNode = xmlNewChild (cur, NULL, BAD_CAST"outline", NULL);
@@ -81,6 +85,9 @@ export_append_node_tag (nodePtr node, gpointer userdata)
 			case NODE_VIEW_SORT_BY_STATE:
 				xmlNewProp (childNode, BAD_CAST"sortColumn", BAD_CAST"state");
 				break;
+			default:
+				g_assert_not_reached();
+				break;
 		}
 
 		if (FALSE == node->sortReversed)
@@ -88,10 +95,16 @@ export_append_node_tag (nodePtr node, gpointer userdata)
 			
 		if (node->loadItemLink)
 			xmlNewProp (childNode, BAD_CAST"loadItemLink", BAD_CAST"true");
-			
-		tmp = g_strdup_printf ("%u", node_get_view_mode(node));
-		xmlNewProp (childNode, BAD_CAST"viewMode", BAD_CAST tmp);
-		g_free (tmp);
+
+		/* Do not export the default view mode setting to avoid making 
+		   it permanent. Do not use node_get_view_mode () here to ensure
+		   that the comparison works as node_get_view_mode () returns
+		   the effective mode! */
+		if (NODE_VIEW_MODE_DEFAULT != node->viewMode) {
+			tmp = g_strdup_printf ("%u", node_get_view_mode(node));
+			xmlNewProp (childNode, BAD_CAST"viewMode", BAD_CAST tmp);
+			g_free (tmp);
+		}
 	}
 	
 	/* 2. add node type specific stuff */
@@ -99,7 +112,7 @@ export_append_node_tag (nodePtr node, gpointer userdata)
 	
 	/* 3. add children */
 	if (internal) {
-		if (ui_node_is_expanded (node->id))
+		if (feed_list_node_is_expanded (node->id))
 			xmlNewProp (childNode, BAD_CAST"expanded", BAD_CAST"true");
 		else
 			xmlNewProp (childNode, BAD_CAST"collapsed", BAD_CAST"true");
@@ -109,7 +122,7 @@ export_append_node_tag (nodePtr node, gpointer userdata)
 		export_node_children (node, childNode, internal);
 }
 
-void
+static void
 export_node_children (nodePtr node, xmlNodePtr cur, gboolean trusted)
 {
 	struct exportData	params;
@@ -159,7 +172,7 @@ export_OPML_feedlist (const gchar *filename, nodePtr node, gboolean trusted)
 
 		xmlSetDocCompressMode (doc, 0);
 
-		if (-1 == xmlSaveFile (backupFilename, doc)) {
+		if (-1 == xmlSaveFormatFile (backupFilename, doc, TRUE)) {
 			g_warning ("Could not export to OPML file!");
 			error = TRUE;
 		}
@@ -170,8 +183,9 @@ export_OPML_feedlist (const gchar *filename, nodePtr node, gboolean trusted)
 		xmlFreeDoc (doc);
 		
 		if (!error) {
+			// FIXME: Use g_rename() once we've reached Glib 2.6+
 			if (rename (backupFilename, filename) < 0) {
-				g_warning (_("Error renaming %s to %s\n"), backupFilename, filename);
+				g_warning (_("Error renaming %s to %s: %s\n"), backupFilename, filename, g_strerror (errno));
 				error = TRUE;
 			}
 		}
@@ -186,7 +200,7 @@ export_OPML_feedlist (const gchar *filename, nodePtr node, gboolean trusted)
 	return !error;
 }
 
-void
+static void
 import_parse_outline (xmlNodePtr cur, nodePtr parentNode, gboolean trusted)
 {
 	gchar		*title, *typeStr, *tmp, *sortStr;
@@ -225,6 +239,10 @@ import_parse_outline (xmlNodePtr cur, nodePtr parentNode, gboolean trusted)
 	}
 	
 	g_assert (NULL != type);
+
+	/* Check if adding this type is allowed */
+	// FIXME: Prevent news bins outside root source
+	// FIXME: Prevent search folders outside root source
 	
 	/* 2. do general node parsing */	
 	node = node_new (type);
@@ -312,7 +330,7 @@ import_parse_outline (xmlNodePtr cur, nodePtr parentNode, gboolean trusted)
 		node->expanded = TRUE;
 	
 	/* 3. Try to load the favicon (needs to be done before adding to the feed list) */
-	node_set_icon (node, favicon_load_from_cache (node->id));
+	node_load_icon (node);
 			
 	/* 4. add to GUI parent */
 	feedlist_node_imported (node);
@@ -329,13 +347,29 @@ import_parse_outline (xmlNodePtr cur, nodePtr parentNode, gboolean trusted)
 	
 	/* 6. do node type specific parsing */
 	NODE_TYPE (node)->import (node, parentNode, cur, trusted);
-	
-	/* 7. update immediately if necessary */
-	if (needsUpdate && (NODE_TYPE(node))) {
-		debug1 (DEBUG_CACHE, "seems to be an import, setting new id: %s and doing first download...", node_get_id(node));
-		subscription_update (node->subscription, 0);
+
+	if (node->subscription) {
+		/* Handle OPML auth info (imported from subscription_import() */
+		if(node->subscription->updateOptions->username) {
+			/* Write to password store (for migration) */
+			liferea_auth_info_store (node->subscription);
+		} else {
+			/* If no auth options in OPML try to import them from the key store */
+			liferea_auth_info_query (node->id);
+		}
+
+		/* 7. update immediately if necessary */
+		if (needsUpdate) {
+			debug1 (DEBUG_CACHE, "seems to be an import, setting new id: %s and doing first download...", node_get_id(node));
+			subscription_update (node->subscription, 0);
+		}
 	}
 
+	/* 8. Always update the node info in the DB to ensure a proper
+	   node entry and parent node information. Search folders would
+	   silentely fail to work without node entry. */
+	db_node_update (node);
+
 	debug_exit ("import_parse_outline");
 }
 
@@ -444,7 +478,7 @@ on_import_activate_cb (const gchar *filename, gpointer user_data)
 void
 import_OPML_file (void)
 {
-	ui_choose_file(_("Import Feed List"), _("Import"), FALSE, on_import_activate_cb, NULL, NULL, "*.opml", _("OPML Files"), NULL);
+	ui_choose_file(_("Import Feed List"), _("Import"), FALSE, on_import_activate_cb, NULL, NULL, "*.opml|*.xml", _("OPML Files"), NULL);
 }
 
 static void
