@@ -1,7 +1,7 @@
 /**
  * @file htmlview.c  item view interface for HTML rendering
  * 
- * Copyright (C) 2006-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2006-2010 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,6 +101,16 @@ htmlview_set_displayed_node (nodePtr node)
 	htmlView_priv.node = node;
 }
 
+gboolean
+htmlview_contains_id (gulong id)
+{
+	gpointer	chunk;
+
+	chunk = g_hash_table_lookup (htmlView_priv.chunkHash, GUINT_TO_POINTER (id));
+
+	return (chunk?TRUE:FALSE);
+}
+
 void
 htmlview_add_item (itemPtr item) 
 {
@@ -191,16 +201,19 @@ htmlview_render_item (itemPtr item,
 	xmlDocPtr 	doc;
 	xmlNodePtr 	xmlNode;
 	const gchar     *text_direction = NULL;
+	gboolean	isMergedItemset;
 
 	debug_enter ("htmlview_render_item");
 
 	/* don't use node from htmlView_priv as this would be
 	   wrong for folders and other merged item sets */
 	node = node_from_id (item->nodeId);
+	
+	isMergedItemset = (node != htmlView_priv.node);
 
 	/* do the XML serialization */
-	doc = xmlNewDoc ("1.0");
-	xmlNode = xmlNewDocNode (doc, NULL, "itemset", NULL);
+	doc = xmlNewDoc (BAD_CAST "1.0");
+	xmlNode = xmlNewDocNode (doc, NULL, BAD_CAST "itemset", NULL);
 	xmlDocSetRootElement (doc, xmlNode);
 				
 	item_to_xml(item, xmlDocGetRootElement (doc));
@@ -209,7 +222,7 @@ htmlview_render_item (itemPtr item,
 			
 	if (IS_FEED (node)) {
 		xmlNodePtr feed;
-		feed = xmlNewChild (xmlDocGetRootElement (doc), NULL, "feed", NULL);
+		feed = xmlNewChild (xmlDocGetRootElement (doc), NULL, BAD_CAST "feed", NULL);
 		feed_to_xml (node, feed);
 	}
 	
@@ -217,11 +230,12 @@ htmlview_render_item (itemPtr item,
 	params = render_parameter_new ();
 	
 	if (NULL != node_get_base_url (node)) {
-		baseUrl = common_uri_escape (node_get_base_url (node));
+		baseUrl = (gchar *) common_uri_escape ( BAD_CAST node_get_base_url (node));
 		render_parameter_add (params, "baseUrl='%s'", baseUrl);
 	}
-	
+
 	render_parameter_add (params, "summary='%d'", summaryMode?1:0);
+	render_parameter_add (params, "showFeedName='%d'", isMergedItemset?1:0);
 	render_parameter_add (params, "single='%d'", (viewMode == ITEMVIEW_SINGLE_ITEM)?1:0);
 	render_parameter_add (params, "txtDirection='%s'", text_direction);
 	render_parameter_add (params, "appDirection='%s'", common_get_app_direction ());
@@ -315,7 +329,7 @@ htmlview_update (LifereaHtmlView *htmlview, itemViewMode mode)
 	itemPtr		item = NULL;
 	gchar		*baseURL = NULL;
 	gboolean	summaryMode;
-		
+
 	/* determine base URL */
 	switch (mode) {
 		case ITEMVIEW_SINGLE_ITEM:
