@@ -1,9 +1,9 @@
 /**
- * @file item.c common item handling
+ * @file item.c item handling
  *
- * Copyright (C) 2003-2012 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2017 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
- *	      
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
+
 #include "item.h"
 
 #include <glib.h>
@@ -36,10 +36,10 @@ itemPtr
 item_new (void)
 {
 	itemPtr		item;
-	
+
 	item = g_new0 (struct item, 1);
 	item->popupStatus = TRUE;
-	
+
 	return item;
 }
 
@@ -58,7 +58,7 @@ item_copy (itemPtr item)
 	item_set_source (copy, item->source);
 	item_set_description (copy, item->description);
 	item_set_id (copy, item->sourceId);
-	
+
 	copy->updateStatus = item->updateStatus;
 	copy->readStatus = item->readStatus;
 	copy->popupStatus = FALSE;
@@ -66,15 +66,15 @@ item_copy (itemPtr item)
 	copy->time = item->time;
 	copy->validGuid = item->validGuid;
 	copy->hasEnclosure = item->hasEnclosure;
-	
+
 	/* the following line allows state propagation in item.c */
 	copy->nodeId = NULL;
 	copy->sourceNr = item->id;
 
 	/* this copies metadata */
 	copy->metadata = metadata_list_copy (item->metadata);
-	
-	/* no deep copy of comments necessary as they are automatically 
+
+	/* no deep copy of comments necessary as they are automatically
 	   retrieved when reading the article */
 
 	return copy;
@@ -84,7 +84,11 @@ void
 item_set_title (itemPtr item, const gchar * title)
 {
 	g_free (item->title);
-	item->title = g_strstrip (g_strdelimit (g_strdup (title), "\r\n", ' '));
+
+	if (title)
+		item->title = g_strstrip (g_strdelimit (g_strdup (title), "\r\n", ' '));
+	else
+		item->title = g_strdup ("");
 }
 
 void
@@ -105,7 +109,7 @@ void
 item_set_source (itemPtr item, const gchar * source)
 {
 	g_free (item->source);
-	if (source) 
+	if (source)
 		item->source = g_strstrip (g_strdup (source));
 	else
 		item->source = NULL;
@@ -123,6 +127,43 @@ const gchar *	item_get_title(itemPtr item) {return item->title; }
 const gchar *	item_get_description(itemPtr item) { return item->description; }
 const gchar *	item_get_source(itemPtr item) { return item->source; }
 
+static GRegex *whitespace_strip_re = NULL;
+
+gchar *
+item_get_teaser (itemPtr item)
+{
+	gchar		*input, *tmpDesc;
+	gchar		*teaser = NULL;
+
+	if (!whitespace_strip_re) {
+		whitespace_strip_re = g_regex_new ("(\n+|\\s\\s+)", G_REGEX_MULTILINE, 0, NULL);
+		g_assert (NULL != whitespace_strip_re);
+	}
+
+	input = unxmlize (g_strdup (item->description));
+	tmpDesc = g_regex_replace_literal (whitespace_strip_re, input, -1, 0, " ", 0, NULL);
+
+	if (strlen (tmpDesc) > 200) {
+		// Truncate hard at pos 200 and search backward for a space
+		tmpDesc[200] = 0;
+		gchar *last_space = g_strrstr (tmpDesc, " ");
+		if (last_space) {
+			*last_space = 0;
+			teaser = tmpDesc;
+		}
+	}
+
+	if (!teaser)
+		return NULL;
+
+	teaser = g_strstrip (g_markup_escape_text (teaser, -1));
+
+	g_free (input);
+	g_free (tmpDesc);
+
+	return teaser;
+}
+
 gchar *
 item_make_link (itemPtr item)
 {
@@ -133,38 +174,24 @@ item_make_link (itemPtr item)
 	if (!src)
 		return NULL;
 
-	/* check for relative link */
-	if (*src == '/') {
+	/* check for absolute URL */
+	if (strstr (src, "://")) {
+		link = g_strdup (src);
+	} else {
 		const gchar * base = item_get_base_url (item);
-		gchar * pos = (gchar *)base;
-		int host_url_size, i;
 
-		/* Find the third /, start of link on
-		 * site. */
-		for (i = 0; pos && i < 3; i++) {
-			pos = strstr(pos + 1, "/");
-		}
-
-		if (!pos) {
+		link = (gchar *) common_build_url (src, base);
+		if (!link) {
 			debug0 (DEBUG_PARSING, "Feed contains relative link and invalid base URL");
 			return NULL;
 		}
-
-		host_url_size = pos - base + 1;
-
-		link = g_malloc (host_url_size + strlen(src));
-		strncpy (link, base, host_url_size - 1);
-		pos = link + host_url_size - 1;
-		strcpy (pos, src);
-	} else {
-		link = g_strdup (src);
 	}
-	
+
 	return link;
 }
 
 void
-item_unload (itemPtr item) 
+item_unload (itemPtr item)
 {
 	g_free (item->title);
 	g_free (item->source);
@@ -173,7 +200,7 @@ item_unload (itemPtr item)
 	g_free (item->commentFeedId);
 	g_free (item->nodeId);
 	g_free (item->parentNodeId);
-	
+
 	g_assert (NULL == item->tmpdata);	/* should be free after rendering */
 	metadata_list_free (item->metadata);
 
@@ -183,63 +210,69 @@ item_unload (itemPtr item)
 const gchar *
 item_get_base_url (itemPtr item)
 {
-	/* item->node is always the source node for the item 
+	/* item->node is always the source node for the item
 	   never a search folder or folder */
 	return node_get_base_url (node_from_id (item->nodeId));
 }
 
 void
-item_to_xml (itemPtr item, xmlNodePtr parentNode)
+item_to_xml (itemPtr item, gpointer xmlNode)
 {
-	xmlNodePtr	duplicatesNode;		
+	xmlNodePtr	parentNode = (xmlNodePtr)xmlNode;
+	xmlNodePtr	duplicatesNode;
 	xmlNodePtr	itemNode;
 	gchar		*tmp;
 	gchar		*tmp2;
-	
-	itemNode = xmlNewChild (parentNode, NULL, "item", NULL);
+
+	itemNode = xmlNewChild (parentNode, NULL, BAD_CAST "item", NULL);
 	g_return_if_fail (itemNode);
 
-	xmlNewTextChild (itemNode, NULL, "title", item_get_title (item)?item_get_title (item):"");
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "title", BAD_CAST (item_get_title (item)?item_get_title (item):""));
 
 	if (item_get_description (item)) {
-		tmp = xhtml_strip_dhtml (item_get_description (item));
+		/* Prefer full article over feed inline content */
+		const gchar *content = metadata_list_get (item->metadata, "richContent");
+		if (NULL == content)
+			content = item_get_description (item);
+
+		tmp = xhtml_strip_dhtml (content);
 		tmp2 = xhtml_strip_unsupported_tags (tmp);
-		xmlNewTextChild (itemNode, NULL, "description", tmp2);
+		xmlNewTextChild (itemNode, NULL, BAD_CAST "description", BAD_CAST tmp2);
 		g_free (tmp);
 		g_free (tmp2);
 	}
-	
+
 	if (item_get_source (item))
-		xmlNewTextChild (itemNode, NULL, "source", item_get_source (item));
+		xmlNewTextChild (itemNode, NULL, BAD_CAST "source", BAD_CAST item_get_source (item));
 
 	tmp = g_strdup_printf ("%ld", item->id);
-	xmlNewTextChild (itemNode, NULL, "nr", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "nr", BAD_CAST tmp);
 	g_free (tmp);
 
 	tmp = g_strdup_printf ("%d", item->readStatus?1:0);
-	xmlNewTextChild (itemNode, NULL, "readStatus", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "readStatus", BAD_CAST tmp);
 	g_free (tmp);
 
 	tmp = g_strdup_printf ("%d", item->updateStatus?1:0);
-	xmlNewTextChild (itemNode, NULL, "updateStatus", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "updateStatus", BAD_CAST tmp);
 	g_free (tmp);
 
 	tmp = g_strdup_printf ("%d", item->flagStatus?1:0);
-	xmlNewTextChild (itemNode, NULL, "mark", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "mark", BAD_CAST tmp);
 	g_free (tmp);
 
 	tmp = g_strdup_printf ("%ld", item->time);
-	xmlNewTextChild (itemNode, NULL, "time", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "time", BAD_CAST tmp);
 	g_free (tmp);
 
 	tmp = date_format (item->time, NULL);
-	xmlNewTextChild (itemNode, NULL, "timestr", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "timestr", BAD_CAST tmp);
 	g_free (tmp);
 
 	if (item->validGuid) {
 		GSList	*iter, *duplicates;
-		
-		duplicatesNode = xmlNewChild(itemNode, NULL, "duplicates", NULL);
+
+		duplicatesNode = xmlNewChild(itemNode, NULL, BAD_CAST "duplicates", NULL);
 		duplicates = iter = db_item_get_duplicates(item->sourceId);
 		while (iter) {
 			gulong id = GPOINTER_TO_UINT (iter->data);
@@ -247,19 +280,19 @@ item_to_xml (itemPtr item, xmlNodePtr parentNode)
 			if (duplicate) {
 				nodePtr duplicateNode = node_from_id (duplicate->nodeId);
 				if (duplicateNode && (item->id != duplicate->id))
-					xmlNewTextChild (duplicatesNode, NULL, "duplicateNode", 
-					                 node_get_title (duplicateNode));
+					xmlNewTextChild (duplicatesNode, NULL, BAD_CAST "duplicateNode",
+					                 BAD_CAST node_get_title (duplicateNode));
 				item_unload (duplicate);
 			}
 			iter = g_slist_next (iter);
 		}
 		g_slist_free (duplicates);
 	}
-		
-	xmlNewTextChild (itemNode, NULL, "sourceId", item->nodeId);
-		
+
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "sourceId", BAD_CAST item->nodeId);
+
 	tmp = g_strdup_printf ("%ld", item->id);
-	xmlNewTextChild (itemNode, NULL, "sourceNr", tmp);
+	xmlNewTextChild (itemNode, NULL, BAD_CAST "sourceNr", BAD_CAST tmp);
 	g_free (tmp);
 
 	metadata_add_xml_nodes (item->metadata, itemNode);
@@ -272,7 +305,7 @@ item_to_xml (itemPtr item, xmlNodePtr parentNode)
 				if (item->commentFeedId)
 					comments_to_xml (itemNode, item->commentFeedId);
 			} else {
-				xmlNewTextChild (itemNode, NULL, "commentsSuppressed", "true");
+				xmlNewTextChild (itemNode, NULL, BAD_CAST "commentsSuppressed", BAD_CAST "true");
 			}
 		}
 	}
