@@ -28,7 +28,7 @@
 #include "metadata.h"
 #include "xml.h"
 
-/* Metadata in Liferea are ordered lists of key/value list pairs. Both 
+/* Metadata in Liferea are ordered lists of key/value list pairs. Both
    feed list nodes and items can have a list of metadata assigned. Metadata
    date values are always text values but maybe of different type depending
    on their usage type. */
@@ -45,9 +45,9 @@ static void
 metadata_init (void)
 {
 	g_assert (NULL == metadataTypes);
-	
+
 	metadataTypes = g_hash_table_new (g_str_hash, g_str_equal);
-	
+
 	/* generic types */
 	metadata_type_register ("author",		METADATA_TYPE_HTML);
 	metadata_type_register ("contributor",		METADATA_TYPE_HTML);
@@ -70,7 +70,8 @@ metadata_init (void)
 	metadata_type_register ("commentFeedUri",	METADATA_TYPE_URL);
 	metadata_type_register ("feedTitle",		METADATA_TYPE_HTML);
 	metadata_type_register ("description",		METADATA_TYPE_HTML);
-	
+	metadata_type_register ("richContent",		METADATA_TYPE_HTML);
+
 	/* types for aggregation NS */
 	metadata_type_register ("agSource",		METADATA_TYPE_URL);
 	metadata_type_register ("agTimestamp",		METADATA_TYPE_TEXT);
@@ -80,7 +81,7 @@ metadata_init (void)
 
 	/* types for creative commons */
 	metadata_type_register ("license",		METADATA_TYPE_HTML);
-	
+
 	/* types for Dublin Core (some dc tags are mapped to feed and item metadata types) */
 	metadata_type_register ("creator",		METADATA_TYPE_HTML);
 	metadata_type_register ("publisher",		METADATA_TYPE_HTML);
@@ -89,20 +90,20 @@ metadata_init (void)
 	metadata_type_register ("identifier",		METADATA_TYPE_HTML);
 	metadata_type_register ("source",		METADATA_TYPE_URL);
 	metadata_type_register ("coverage",		METADATA_TYPE_HTML);
-	
+
 	/* types for photo blogs */
 	metadata_type_register ("photo", 		METADATA_TYPE_URL);
 
 	/* types for slash */
 	metadata_type_register ("slash",		METADATA_TYPE_HTML);
-	
+
 	/* type for gravatars */
 	metadata_type_register ("gravatar",		METADATA_TYPE_URL);
-	
+
 	/* for RSS 2.0 real source and newsbin real source info */
 	metadata_type_register ("realSourceUrl",	METADATA_TYPE_URL);
 	metadata_type_register ("realSourceTitle",	METADATA_TYPE_URL);
-	
+
 	/* for trackback URL */
 	metadata_type_register ("related",		METADATA_TYPE_URL);
 	metadata_type_register ("via",                  METADATA_TYPE_URL);
@@ -117,8 +118,8 @@ void
 metadata_type_register (const gchar *name, gint type)
 {
 	if (!metadataTypes)
-		metadata_init ();	
-	
+		metadata_init ();
+
 	g_hash_table_insert (metadataTypes, (gpointer)name, GINT_TO_POINTER (type));
 }
 
@@ -138,14 +139,14 @@ static gint
 metadata_get_type (const gchar *name)
 {
 	gint	type;
-	
+
 	if (!metadataTypes)
 		metadata_init ();
 
 	type = GPOINTER_TO_INT (g_hash_table_lookup (metadataTypes, (gpointer)name));
 	if (0 == type)
 		g_warning ("Unknown metadata type: %s, please report this Liferea bug!", name);
-	
+
 	return type;
 }
 
@@ -164,10 +165,10 @@ metadata_list_append (GSList *metadata, const gchar *strid, const gchar *data)
 	GSList		*iter = metadata;
 	gchar		*tmp, *checked_data = NULL;
 	struct pair 	*p;
-	
+
 	if (!data)
 		return metadata;
-	
+
 	/* lookup type and check format */
 	switch (metadata_get_type (strid)) {
 		case METADATA_TYPE_TEXT:
@@ -181,7 +182,7 @@ metadata_list_append (GSList *metadata, const gchar *strid, const gchar *data)
 			} else {
 				checked_data = common_uri_escape (data);
 			}
-			
+
 			/* finally strip whitespace */
 			checked_data = g_strchomp (checked_data);
 			break;
@@ -201,9 +202,9 @@ metadata_list_append (GSList *metadata, const gchar *strid, const gchar *data)
 			g_free (tmp);
 			break;
 	}
-	
+
 	while (iter) {
-		p = (struct pair*)iter->data; 
+		p = (struct pair*)iter->data;
 		if (g_str_equal (p->strid, strid)) {
 			/* Avoid duplicate values */
 			if (NULL == g_slist_find_custom (p->data, checked_data, metadata_value_cmp))
@@ -226,9 +227,9 @@ metadata_list_set (GSList **metadata, const gchar *strid, const gchar *data)
 {
 	GSList	*iter = *metadata;
 	struct pair *p;
-	
+
 	while (iter) {
-		p = (struct pair*)iter->data; 
+		p = (struct pair*)iter->data;
 		if (g_str_equal (p->strid, strid)) {
                         g_slist_free_full (p->data, g_free);
                         p->data = g_slist_append (NULL, g_strdup (data));
@@ -247,9 +248,9 @@ metadata_list_foreach (GSList *metadata, metadataForeachFunc func, gpointer user
 {
 	GSList	*list = metadata;
 	guint	index = 0;
-	
+
 	while (list) {
-		struct pair *p = (struct pair*)list->data; 
+		struct pair *p = (struct pair*)list->data;
 		GSList *values = (GSList *)p->data;
 		while (values) {
 			index++;
@@ -264,9 +265,9 @@ GSList *
 metadata_list_get_values (GSList *metadata, const gchar *strid)
 {
 	GSList *list = metadata;
-	
+
 	while (list) {
-		struct pair *p = (struct pair*)list->data; 
+		struct pair *p = (struct pair*)list->data;
 		if (g_str_equal (p->strid, strid))
 			return p->data;
 		list = list->next;
@@ -278,7 +279,7 @@ const gchar *
 metadata_list_get (GSList *metadata, const gchar *strid)
 {
 	GSList	*values;
-	
+
 	values = metadata_list_get_values (metadata, strid);
 	return values?values->data:NULL;
 
@@ -290,7 +291,7 @@ metadata_list_copy (GSList *list)
 	GSList		*copy = NULL;
 	GSList		*iter2, *iter = list;
 	struct pair	*p;
-	
+
 	while (iter) {
 		p = (struct pair*)iter->data;
 		iter2 = p->data;
@@ -300,7 +301,7 @@ metadata_list_copy (GSList *list)
 		}
 		iter = iter->next;
 	}
-	
+
 	return copy;
 }
 
@@ -308,7 +309,7 @@ void
 metadata_list_free (GSList *metadata)
 {
 	GSList *iter = metadata;
-	
+
 	while (iter) {
 		struct pair *p = (struct pair*)iter->data;
                 g_slist_free_full (p->data, g_free);
@@ -325,9 +326,9 @@ metadata_add_xml_nodes (GSList *metadata, xmlNodePtr parentNode)
 	GSList *list = metadata;
 	xmlNodePtr attribute;
 	xmlNodePtr metadataNode = xmlNewChild (parentNode, NULL, "attributes", NULL);
-	
+
 	while (list) {
-		struct pair *p = (struct pair*)list->data; 
+		struct pair *p = (struct pair*)list->data;
 		GSList *list2 = p->data;
 		while (list2) {
 			attribute = xmlNewTextChild (metadataNode, NULL, "attribute", list2->data);
@@ -337,4 +338,3 @@ metadata_add_xml_nodes (GSList *metadata, xmlNodePtr parentNode)
 		list = list->next;
 	}
 }
-
