@@ -1,7 +1,7 @@
-/**
+/*
  * @file node_view.h  node view modes
  * 
- * Copyright (C) 2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2009-2012 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,16 +22,17 @@
 #define _NODE_VIEW_H
 
 typedef enum {
-	NODE_VIEW_MODE_INVALID,
 	NODE_VIEW_MODE_NORMAL	= 0,
 	NODE_VIEW_MODE_WIDE	= 1,
-	NODE_VIEW_MODE_COMBINED	= 2
+	NODE_VIEW_MODE_COMBINED	= 2,
+	NODE_VIEW_MODE_DEFAULT,
 } nodeViewType;
 
 typedef enum {
 	NODE_VIEW_SORT_BY_TIME = 0,	/* default */
 	NODE_VIEW_SORT_BY_TITLE,
-	NODE_VIEW_SORT_BY_PARENT
+	NODE_VIEW_SORT_BY_PARENT,
+	NODE_VIEW_SORT_BY_STATE
 } nodeViewSortType;
 
 #endif
