@@ -20,6 +20,7 @@
 
 #include "subscription.h"
 
+#include <math.h>
 #include <string.h>
 
 #include "auth.h"
@@ -200,6 +201,11 @@ subscription_process_update_result (const struct updateResult * const result, gp
 	nodePtr		node = subscription->node;
 	gboolean	processing = FALSE;
 	GTimeVal	now;
+	gint		next_update = 0;
+	gint		update_time_sources = 0;
+	gint		maxage = -1;
+	gint		syn_update = -1;
+	gint		ttl = subscription->updateState->timeToLive = -1;
 
 	/* 1. preprocessing */
 
@@ -224,6 +230,7 @@ subscription_process_update_result (const struct updateResult * const result, gp
 		processing = TRUE;
 	}
 
+	
 	subscription_update_error_status (subscription, result->httpstatus, result->returncode, result->filterErrors);
 
 	subscription->updateJob = NULL;
@@ -232,13 +239,46 @@ subscription_process_update_result (const struct updateResult * const result, gp
 	if (processing)
 		SUBSCRIPTION_TYPE (subscription)->process_update_result (subscription, result, flags);
 
-	/* 3. call favicon updating after subscription processing
+	/* 3. set default update interval */
+	update_state_set_cache_maxage (subscription->updateState, update_state_get_cache_maxage (result->updateState));
+	maxage = subscription->updateState->maxAgeMinutes;
+
+	if (0 < subscription->updateState->synFrequency &&
+		0 < subscription->updateState->synPeriod) {
+		syn_update = ceil ( (float) (subscription->updateState->synPeriod / subscription->updateState->synFrequency) );
+	} else if (0 < subscription->updateState->synPeriod) {
+		syn_update = subscription->updateState->synPeriod;
+	}
+	if (0 < subscription->updateState->timeToLive) {
+		ttl = subscription->updateState->timeToLive;
+	}
+
+	if (0 < maxage    ) { update_time_sources++; next_update += maxage;     }
+	if (0 < syn_update) { update_time_sources++; next_update += syn_update; }
+	if (0 < ttl       ) { update_time_sources++; next_update += ttl;        }
+	
+	if (0 < update_time_sources) {
+		/* enforce a 5 minute minimum update interval.
+		   round up to nearest 5-minute block to coalesce updates (battery optimization). */
+		next_update = ceil ((float) (next_update / update_time_sources));
+		next_update -= next_update % 5;
+		if (5 > next_update) {
+			next_update = 5;
+		}
+	} else {
+		next_update = -1;
+	}
+
+	debug1 (DEBUG_UPDATE, "The next suggested update time is in %d minutes.", next_update);
+	subscription_set_default_update_interval (subscription, next_update);
+
+	/* 4. call favicon updating after subscription processing
 	      to ensure we have valid baseUrl for feed nodes... */
 	g_get_current_time (&now);
 	if (favicon_update_needed (subscription->node->id, subscription->updateState, &now))
 		subscription_update_favicon (subscription);
 	
-	/* 4. generic postprocessing */
+	/* 5. generic postprocessing */
 	update_state_set_lastmodified (subscription->updateState, update_state_get_lastmodified (result->updateState));
 	update_state_set_cookies (subscription->updateState, update_state_get_cookies (result->updateState));
 	update_state_set_etag (subscription->updateState, update_state_get_etag (result->updateState));
