@@ -1,7 +1,7 @@
 /**
  * @file subscription.h  common subscription handling interface
  * 
- * Copyright (C) 2003-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2012 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,13 +36,7 @@ enum cache_limit {
 /** Flags used in the request structure */
 enum feed_request_flags {
 	FEED_REQ_RESET_TITLE		= (1<<0),	/**< Feed's title should be reset to default upon update */
-	/* FEED_REQ_RESET_UPDATE_INT is not used anymore */
-	/* FEED_REQ_AUTO_DISCOVER is not used anymore */
 	FEED_REQ_PRIORITY_HIGH		= (1<<3),	/**< set to signal that this is an important user triggered request */
-	/* FEED_REQ_DOWNLOAD_FAVICON is not used anymore */
-	/* FEED_REQ_AUTH_DIALOG is not used anymore */
-	FEED_REQ_ALLOW_RETRIES		= (1<<6),	/**< set to allow fetch retries on network errors */
-	FEED_REQ_NO_PROXY		= (1<<7)	/**< sets no proxy flag */
 };
  
 /** Common structure to hold all information about a single subscription. */
@@ -73,17 +67,6 @@ typedef struct subscription {
 	gchar		*filterError;		/**< textual description of filter errors */
 } *subscriptionPtr;
 
-/**
- * Generic update result processing callback type.
- * This callback must not free the result structure. It will be
- * free'd by the download system after the callback returns.
- *
- * @param node		the subscriptions node
- * @param result	the update result
- * @param flags		update result processing flags
- */
-typedef void (*subscription_update_cb) (nodePtr node, const struct updateResult * const result, guint32 flags);
-
 /**
  * Create a new subscription structure.
  *
@@ -122,15 +105,6 @@ void subscription_export (subscriptionPtr subscription, xmlNodePtr xml, gboolean
  */
 void subscription_to_xml (subscriptionPtr subscription, xmlNodePtr xml);
 
-/**
- * Checks wether a subscription is ready to be updated
- *
- * @param subscription	the subscription to check
- *
- * @returns TRUE if subscription can be updated
- */
-gboolean subscription_can_be_updated(subscriptionPtr subscription);
-
 /**
  * Triggers updating a subscription. Will download the 
  * the document indicated by the source URL of the subscription.
@@ -143,7 +117,7 @@ gboolean subscription_can_be_updated(subscriptionPtr subscription);
 void subscription_update (subscriptionPtr subscription, guint flags);
 
 /**
- * Called when auto updating. Checks wether the subscription
+ * Called when auto updating. Checks whether the subscription
  * needs to be updated (according to it's update interval) and
  * if necessary calls subscription_update().
  *
@@ -220,23 +194,6 @@ const gchar * subscription_get_source(subscriptionPtr subscription);
  */
 void subscription_set_source(subscriptionPtr subscription, const gchar *source);
 
-/**
- * Get the original subscription URL
- *
- * @param subscription	the subscription
- *
- * @returns the original source URL
- */
-const gchar * subscription_get_orig_source(subscriptionPtr subscription);
-
-/**
- * Set the original subscription URL
- *
- * @param subscription	the subscription
- * @param source	the new original source URL
- */ 
-void subscription_set_orig_source(subscriptionPtr subscription, const gchar *source);
-
 /**
  * Returns the homepage URL of the given subscription.
  *
@@ -273,6 +230,15 @@ const gchar * subscription_get_filter(subscriptionPtr subscription);
  */
 void subscription_set_filter(subscriptionPtr subscription, const gchar * filter);
 
+/**
+ * Set authentication information for a given subscription
+ * 
+ * @param subscription	the subscription
+ * @param username	the user name
+ * @param password	the password
+ */
+void subscription_set_auth_info (subscriptionPtr subscription, const gchar *username, const gchar *password);
+
 /**
  * Frees the given subscription structure.
  *
