@@ -35,6 +35,7 @@
 #include "newsbin.h"
 #include "vfolder.h"
 #include "ui/browser_tabs.h"
+#include "ui/liferea_dialog.h"
 #include "ui/liferea_shell.h"
 #include "ui/subscription_dialog.h"
 #include "ui/ui_dnd.h"
@@ -66,25 +67,36 @@ feed_list_view_selection_changed_cb (GtkTreeSelection *selection, gpointer data)
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 	 	gtk_tree_model_get (model, &iter, FS_PTR, &node, -1);
 
-		debug1 (DEBUG_GUI, "feed list selection changed to \"%s\"", node_get_title(node));
+		debug1 (DEBUG_GUI, "feed list selection changed to \"%s\"", node?node_get_title (node):"Empty node");
 
-		browser_tabs_show_headlines ();		// FIXME: emit signal to item list instead of bother the tabs manager
-		
-		/* 1.) update feed list and item list states */
-		feedlist_selection_changed (node);
-
-		/* 2.) Refilter the GtkTreeView to get rid of nodes with 0 unread 
-		   messages when in reduced mode. */
-		gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (filter));
-		
-		if (node) {
+		if (!node) {
+			/* The selected iter is an "empty" node added to an empty folder. We get the parent's node
+			 * to set it as the selected node. This is useful if the user adds a feed, the folder will
+			 * be used as location for the new node. */
+			GtkTreeIter parent;
+			if (gtk_tree_model_iter_parent (model, &parent, &iter))
+				gtk_tree_model_get (model, &parent, FS_PTR, &node, -1);
+			else {
+				debug0 (DEBUG_GUI, "A selected null node has no parent. This should not happen.");
+				return;
+			}
+			liferea_shell_update_feed_menu (TRUE, FALSE, FALSE);
+		} else {
 			gboolean allowModify = (NODE_SOURCE_TYPE (node->source->root)->capabilities & NODE_SOURCE_CAPABILITY_WRITABLE_FEEDLIST);
 			liferea_shell_update_update_menu ((NODE_TYPE (node)->capabilities & NODE_CAPABILITY_UPDATE) ||
 			                                  (NODE_TYPE (node)->capabilities & NODE_CAPABILITY_UPDATE_CHILDS));
 			liferea_shell_update_feed_menu (allowModify, TRUE, allowModify);
-		} else {
-			liferea_shell_update_feed_menu (TRUE, FALSE, FALSE);
 		}
+
+		browser_tabs_show_headlines ();		// FIXME: emit signal to item list instead of bother the tabs manager
+
+		/* 1.) update feed list and item list states */
+		feedlist_selection_changed (node);
+
+		/* 2.) Refilter the GtkTreeView to get rid of nodes with 0 unread
+		   messages when in reduced mode. */
+		gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (filter));
+
 	} else {
 		/* If we cannot get the new selection we keep the old one
 		   this happens when we're doing drag&drop for example. */
@@ -353,7 +365,7 @@ feed_list_view_select (nodePtr node)
 }
 
 void
-on_menu_properties (GtkMenuItem *menuitem, gpointer user_data)
+on_menu_properties (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
 	nodePtr node = feedlist_get_selected ();
 	
@@ -361,7 +373,7 @@ on_menu_properties (GtkMenuItem *menuitem, gpointer user_data)
 }
 
 void
-on_menu_delete(GtkWidget *widget, gpointer user_data)
+on_menu_delete(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
 	feed_list_node_remove (feedlist_get_selected ());
 }
@@ -377,9 +389,14 @@ do_menu_update (nodePtr node)
 }
 
 void
-on_menu_update (void)
+on_menu_update (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	nodePtr node = feedlist_get_selected ();
+	nodePtr node = NULL;
+
+	if (user_data)
+		node = (nodePtr) user_data;
+	else
+		node = feedlist_get_selected ();
 
 	if (node)
 		do_menu_update (node);
@@ -388,55 +405,86 @@ on_menu_update (void)
 }
 
 void
-on_menu_update_all(void)
+on_menu_update_all(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
 	do_menu_update (feedlist_get_root ());
 }
 
 void
-on_menu_allread (GtkWidget *widget, gpointer user_data)
+on_action_mark_all_read (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {	
-	feedlist_mark_all_read (feedlist_get_selected ());
+	nodePtr 	feedlist;
+	gboolean 	confirm_mark_read;
+	gboolean 	do_mark_read = TRUE;
+
+	if (!g_strcmp0 (g_action_get_name (G_ACTION (action)), "mark-all-feeds-read"))
+		feedlist = feedlist_get_root ();
+	else if (user_data)
+		feedlist = (nodePtr) user_data;
+	else
+		feedlist = feedlist_get_selected ();
+
+	conf_get_bool_value (CONFIRM_MARK_ALL_READ, &confirm_mark_read);
+
+	if (confirm_mark_read) {
+		gint result;
+		GtkMessageDialog *confirm_dialog = GTK_MESSAGE_DIALOG (liferea_dialog_new ("mark_read_dialog"));
+		GtkWidget *dont_ask_toggle = liferea_dialog_lookup (GTK_WIDGET (confirm_dialog), "dontAskAgainToggle");
+		const gchar *feed_title = (feedlist_get_root () == feedlist) ? _("all feeds"):node_get_title (feedlist);
+		gchar *primary_message = g_strdup_printf (_("Mark %s as read ?"), feed_title);
+
+		g_object_set (confirm_dialog, "text", primary_message, NULL);
+		g_free (primary_message);
+		gtk_message_dialog_format_secondary_text (confirm_dialog, _("Are you sure you want to mark all items in %s as read ?"), feed_title);
+
+		conf_bind (CONFIRM_MARK_ALL_READ, dont_ask_toggle, "active", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_INVERT_BOOLEAN);
+
+		result = gtk_dialog_run (GTK_DIALOG (confirm_dialog));
+		if (result != GTK_RESPONSE_OK)
+			do_mark_read = FALSE;
+		gtk_widget_destroy (GTK_WIDGET (confirm_dialog));
+	}
+
+	if (do_mark_read)
+		feedlist_mark_all_read (feedlist);
 }
 
 void
-on_menu_allfeedsread (GtkWidget *widget, gpointer user_data)
-{
-	feedlist_mark_all_read (feedlist_get_root ());
-}
-
-void
-on_menu_feed_new (GtkMenuItem *menuitem, gpointer user_data)
+on_menu_feed_new (GSimpleAction *menuitem, GVariant *parameter, gpointer user_data)
 {
 	node_type_request_interactive_add (feed_get_node_type ());
 }
 
 void
-on_new_plugin_activate (GtkMenuItem *menuitem, gpointer user_data)
+on_new_plugin_activate (GSimpleAction *menuitem, GVariant *parameter, gpointer user_data)
 {
 	node_type_request_interactive_add (node_source_get_node_type ());
 }
 
 void
-on_new_newsbin_activate (GtkMenuItem *menuitem, gpointer user_data)
+on_new_newsbin_activate (GSimpleAction *menuitem, GVariant *parameter, gpointer user_data)
 {
 	node_type_request_interactive_add (newsbin_get_node_type ());
 }
 
 void
-on_menu_folder_new (GtkMenuItem *menuitem, gpointer user_data)
+on_menu_folder_new (GSimpleAction *menuitem, GVariant *parameter, gpointer user_data)
 {
 	node_type_request_interactive_add (folder_get_node_type ());
 }
 
 void
-on_new_vfolder_activate (GtkMenuItem *menuitem, gpointer user_data)
+on_new_vfolder_activate (GSimpleAction *menuitem, GVariant *parameter, gpointer user_data)
 {
 	node_type_request_interactive_add (vfolder_get_node_type ());
 }
 
 void
-on_feedlist_reduced_activate (GtkToggleAction *menuitem, gpointer user_data)
+on_feedlist_reduced_activate (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	feed_list_view_set_reduce_mode (gtk_toggle_action_get_active (menuitem));
+	GVariant *state = g_action_get_state (action);
+	gboolean val = !g_variant_get_boolean (state);
+	feed_list_view_set_reduce_mode (val);
+	g_simple_action_set_state (action, g_variant_new_boolean (val));
+	g_object_unref (state);
 }
