@@ -1,7 +1,7 @@
 /**
  * @file update.h  generic update request and state processing
  *
- * Copyright (C) 2003-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2014 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,10 +26,9 @@
 #include <glib.h>
 
 /* Update requests do represent feed updates, favicon and enclosure 
-   downloads and (if GtkHTML2 is used) HTML browser traffic. A request can 
-   be started synchronously or asynchronously. In the latter case it
-   can be cancelled at any time. If the processing of a update request is
-   done the request callback will be triggered. 
+   downloads. A request can be started synchronously or asynchronously.
+   In the latter case it can be cancelled at any time. If the processing
+   of a update request is done the request callback will be triggered. 
    
    A request can have an update state assigned. This is to support
    the different bandwidth saving methods. For caching along feeds
@@ -43,17 +42,6 @@
    requests are still processed. Currently running downloads are 
    not terminated. */
 
-/* Maximum number of retries that can be done */
-#define REQ_MAX_NUMBER_OF_RETRIES 3
-
-/* Delay (in seconds) to wait before the first retry.
- * It will then increase for the later ones. */
-#define REQ_MIN_DELAY_FOR_RETRY 30
-
-/* Maximum delay (in seconds) beetween two retries. Useful to avoid 
- * stupidly long waits if REQ_MAX_NUMBER_OF_RETRIES is high. */
-#define REQ_MAX_DELAY_FOR_RETRY 500
-
 typedef enum {
 	REQUEST_STATE_INITIALIZED = 0,	/**< request struct newly created */
 	REQUEST_STATE_PENDING,		/**< request added to download queue */
@@ -91,6 +79,11 @@ typedef struct updateState {
 	GTimeVal	lastPoll;		/**< time at which the feed was last updated */
 	GTimeVal	lastFaviconPoll;	/**< time at which the feeds favicon was last updated */
 	gchar		*cookies;		/**< cookies to be used */	
+	gchar		*etag;			/**< ETag sent by the server */
+	gint		maxAgeMinutes;		/**< default update interval, greatest value sourced from HTTP and XML */
+	gint		synFrequency;		/**< syn:updateFrequency */
+	gint		synPeriod;		/**< syn:updatePeriod */
+	gint		timeToLive;		/**< ttl */
 } *updateStatePtr;
 
 /** structure describing a HTTP update request */
@@ -104,7 +97,6 @@ typedef struct updateRequest {
 	gchar           *authValue;     /**< Custom value for Authorization: header */
 	updateOptionsPtr options;	/**< Update options for the request */
 	gchar		*filtercmd;	/**< Command will filter output of URL */
-	gboolean	allowRetries;	/**< Allow download retries on network errors */
 	updateStatePtr	updateState;	/**< Update state of the requested object (etags, last modified...) */
 } *updateRequestPtr;
 
@@ -118,7 +110,6 @@ typedef struct updateResult {
 	gchar		*data;		/**< Downloaded data */
 	size_t		size;		/**< Size of downloaded data */
 	gchar		*contentType;	/**< Content type of received data */
-	gushort		retriesCount;	/**< Count how many retries have been done */	 
 	gchar		*filterErrors;	/**< Error messages from filter execution */
 	
 	updateStatePtr	updateState;	/**< New update state of the requested object (etags, last modified...) */
@@ -145,6 +136,12 @@ updateStatePtr update_state_new (void);
 glong update_state_get_lastmodified (updateStatePtr state);
 void update_state_set_lastmodified (updateStatePtr state, glong lastmodified);
 
+const gchar * update_state_get_etag (updateStatePtr state);
+void update_state_set_etag (updateStatePtr state, const gchar *etag);
+
+gint update_state_get_cache_maxage (updateStatePtr state);
+void update_state_set_cache_maxage (updateStatePtr state, const gint maxage);
+
 const gchar * update_state_get_cookies (updateStatePtr state);
 void update_state_set_cookies (updateStatePtr state, const gchar *cookies);
 
@@ -270,17 +267,6 @@ void update_process_finished_job (updateJobPtr job);
  */
 void update_job_cancel_by_owner (gpointer owner);
 
-/**
- * Cancel a request if it is waiting to be retried.
- * In case of success, the job is free'd when its retry timeout expires,
- * so it is safe to just forget about it.
- * 
- * @param job		the update job
- *
- * @return TRUE if successfully cancelled the job
- */
-gboolean update_job_cancel_retry (updateJobPtr job);
-
 /**
  * Method to query the update state of currently processed jobs.
  *
